@@ -20,18 +20,18 @@ from selenium import webdriver
 from selenium.webdriver.firefox.options import Options
 from selenium.webdriver.common.keys import Keys
 from selenium.common.exceptions import StaleElementReferenceException
+from selenium.common.exceptions import NoSuchElementException
 from time import sleep
 import re
 
 
 class Cleverbot:
-
     '''
     Constructs a Cleverbot chat session. Initializes the options
     to connect to Cleverbot.com via a headless Firefox browser using
     selenium, and contains the functions to connect and create chat
     sessions. Every request has the possiblity for a BrokenPipeError
-    so I looped all requests until there is no error recieved.
+    so I looped all requests until there is no error received.
     '''
 
     def __init__(self):
@@ -44,7 +44,6 @@ class Cleverbot:
         self.hacking = False
         self.count = -1
 
-    
     def get_form(self):
 
         # find the form tag to enter your message
@@ -60,7 +59,6 @@ class Cleverbot:
                 continue
             break
 
-
     def send_input(self, userInput):
 
         # submits your message
@@ -76,13 +74,12 @@ class Cleverbot:
                 continue
             break
 
-
     def get_response(self):
 
         '''
         The DOM is updated with every individual character
-        recieved from the Cleverbot app. This tries to make 
-        sure that the DOM element has recieve the full text
+        received from the Cleverbot app. This tries to make 
+        sure that the DOM element has receive the full text
         before continuing the function.
         '''
 
@@ -90,34 +87,30 @@ class Cleverbot:
         while self.hacking == False:
             try:
                 while True:
-
-                    # tries to collect the full response
                     try:
-                        line = self.browser.find_element_by_id('line1')
-                        sleep(3)
-                        newLine = self.browser.find_element_by_id('line1')
-                        if line.text != newLine and newLine.text != ' ' and newLine.text != '':
+                        if "opacity: 0.1" in self.browser.find_element_by_xpath("//span[@id='snipTextIcon']").get_attribute(
+                                "style"):
                             line = self.browser.find_element_by_id('line1')
-                            sleep(3)
                             break
+                    except NoSuchElementException:
+                        continue
                     except StaleElementReferenceException:
                         self.url = self.url + '/?' + str(int(self.count + 1))
                         continue
             except BrokenPipeError:
                 continue
             break
-        if self.hacking == True:
+        if self.hacking is True:
             self.botResponse = 'Silly rabbit, html is for skids.'
-        elif self.hacking == False:
+        elif self.hacking is False:
             self.botResponse = line.text
         self.hacking = False
         return self.botResponse
 
-
     def single_exchange(self, userInput):
 
         '''
-        This fuction is used to create a single send a recieve chat
+        This fuction is used to create a single send a receive chat
         session via a headless Firefox browser, sending your input
         as an argument to the DOM Form to be passed to the JS
         cleverbot.sendAI() function and retrieving it's response
@@ -135,4 +128,3 @@ class Cleverbot:
         self.send_input(userInput)
         self.get_response()
         return self.botResponse
-
